<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/svp?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// A
	'action_patienter' => 'Vykonávajú sa akcie. Prosím, počkajte.',
	'actions' => 'Akcie',
	'actions_a_faire' => 'Akcie, ktoré treba vykonať',
	'actions_demandees' => 'Vyžadované akcie:',
	'actions_en_erreur' => 'Chyby, ktoré sa vyskytli',
	'actions_necessaires' => 'Budú vykonané tieto dodatočné akcie:',
	'actions_non_traitees' => 'Nevykonané akcie',
	'actions_realises' => 'Vykonané akcie',
	'afficher_les_plugins_incompatibles' => 'Zobraziť nekompatibilné zásuvné moduly',
	'alerte_compatibilite' => 'Vynútená kompatibilita',
	'alerte_compatibilite_version_autorisee' => 'Možno aktivovať zásuvné moduly kompatibilné s verziou SPIPu <code>@version@</code>.',

	// B
	'bouton_activer' => 'Aktivovať',
	'bouton_actualiser' => 'Aktualizovať',
	'bouton_actualiser_tout' => 'Aktualizovať depozitáre',
	'bouton_appliquer' => 'Použiť',
	'bouton_confirmer' => 'Potvrdiť',
	'bouton_desactiver' => 'Deaktivovať',
	'bouton_desinstaller' => 'Odinštalovať',
	'bouton_installer' => 'Stiahnuť a aktivovať',
	'bouton_modifier_depot' => 'Zmeniť depozitár',
	'bouton_supprimer' => 'Odstrániť',
	'bouton_up' => 'Aktualizovať',
	'bulle_actualiser_depot' => 'Aktualizovať balíky v depozitári',
	'bulle_actualiser_tout_depot' => 'Aktualizovať balíky vo všetkých depozitároch',
	'bulle_afficher_xml_plugin' => 'Obsah súboru XML zásuvného modulu',
	'bulle_ajouter_spipzone' => 'Pridať depozitár SPIP-Zone',
	'bulle_aller_demonstration' => 'Prejdete na stránku s ukážkou',
	'bulle_aller_depot' => 'Prejsť na stránku tohto depozitára',
	'bulle_aller_documentation' => 'Prejsť na stránku dokumentácie',
	'bulle_aller_plugin' => 'Prejsť na stránku zásuvného modulu',
	'bulle_supprimer_depot' => 'Odstrániť depozitár a jeho balíky',
	'bulle_telecharger_archive' => 'Stiahnuť archív',
	'bulle_telecharger_fichier_depot' => 'Stiahnuť súbor XML depozitára',
	'bulle_telecharger_librairie' => 'Stiahnuť knižnicu',

	// C
	'cacher_les_plugins_incompatibles' => 'Schovať nekompatibilné zásuvné moduly',
	'config_activer_log_verbeux' => 'Aktivovať podrobné protokoly?',
	'config_activer_log_verbeux_explication' => 'Táto možnosť zabezpečí, že protokoly SVP bud podrobnejšie…',
	'config_activer_pas_a_pas' => 'Aktivovať režim Krok za krokom?',
	'config_activer_pas_a_pas_explication' => 'Ak aktivujete tento režim, po vykonaní každej akcie sa zobrazí záznam  namiesto súhrnného prehľadu všetkých vykonaných zmien po vykonaní všetkých akcií.',
	'config_activer_runtime' => 'Aktivovať režim runtime?',
	'config_activer_runtime_explication' => '		V režime runtime (áno) spúšťa iba zásuvné moduly kompatibilné s vašou verziou SPIPu,
		čo sa veľmi odporúča pre väčšinu využití programu.
		
		V režime runtime nie (nie), sa všetky zásuvné moduly spúšťajú cez depozitár
		bez ohľadu na aktuálnu verziu SPIPu. To je dobré iba 
		na využitie SVP na zobrazenie všetkých existujúcich zásuvných modulov ako to robí stránka Plugins SPIP (plugins.spip.net)',
	'config_autoriser_activer_paquets_obsoletes' => 'Umožniť aktiváciu zastaralých balíkov?',
	'config_autoriser_activer_paquets_obsoletes_explication' => 'Zastaralé balíky sú balíky,
		ktoré sú lokálne dostupné a ktoré sú staršie ako ostatné lokálne balíky. Zastaranosť
		sa určuje podľa stavu balíka (stabilné, testovacie, vo vývoji) a podľa
		verzie.

		Ak stále chcete aktivovať tieto zastaralé zásuvné moduly, aktivujte túto možnosť.
		',
	'config_depot_editable' => 'Umožniť upravovanie depozitárov?',
	'config_depot_editable_explication' => 'Umožňuje upravovať údaje v depozitári a priradiť k ním kľúčové slová alebo dokumenty.
		Táto možnosť by mala zaujať každého! Radšej preto nenechajte možnosť "nie"!',
	'confirmer_desinstaller' => 'Pozor, odinštalovanie zásuvného modulu <b>vymaže</b> jeho údaje z databázy a nedá sa vrátiť späť.<br />Ak teda s istotou neviete, či to chcete určite urobiť, zásuvný modul len deaktivujte.',
	'confirmer_telecharger_dans' => 'Zásuvný modul, ktorý bude nahraný do priečonka (@dir@), už existuje.
	Prepíšete tak obsah tohto priečinka.
	Kópia starého obsahu bude uložená v priečinku "@dir_backup@".
		Túto akciu musíte potvrdiť.',

	// E
	'erreur_actions_non_traitees' => 'Niektoré akcie neboli vykonané.
			Mohlo sa to stať kvôli chybám v akciách, ktoré bolo treba vykonať, alebo kvôli chybe v zobrazení tejto stránky, zatiaľčo akcie čakajú, kým budú vykonané. Akcie spustil(a) @auteur@ @date@.',
	'erreur_auth_plugins_ajouter_lib' => 'Na pridanie knižnice nemáte potrebné práva.',
	'erreur_dir_dib_ecriture' => 'Do adresára knižníc @dir@ sa nedá zapisovať. Knižnica sa nedá spustiť!',
	'erreur_dir_dib_indefini' => 'Priečinok _DIR_LIB nie je definovaný. Knižnica sa nedá spustiť!',
	'erreur_dir_plugins_auto' => 'Priečinok "plugins/auto" na stiahnutie balíkov
		nebol vytvorený alebo sa doň nedá zapisovať.
		<strong>Musíte ho vytvoriť, aby ste si pomocou tohto rozhrania mohli nainštalovať nové zásuvné moduly.</strong>',
	'erreur_dir_plugins_auto_ecriture' => 'Do priečinka s balíkmi @dir@ sa nedá zapisovať. Balík sa nedá spustiť!',
	'erreur_dir_plugins_auto_indefini' => 'Priečinok _DIR_PLUGIN_AUTO nie je definovaný. Balík sa nedá spustiť!', # MODIF
	'erreur_dir_plugins_auto_titre' => 'K umiestneniu "plugins/auto" sa nedá dostať!',
	'erreur_teleporter_chargement_source_impossible' => 'Zdroj @source@ sa nedá nahrať',
	'erreur_teleporter_destination_erreur' => 'Program na premiestňovanie nemá prístup k priečinku @dir@',
	'erreur_teleporter_echec_deballage_archive' => 'Súbor @fichier@ sa nedá rozbaliť',
	'erreur_teleporter_format_archive_non_supporte' => 'Premiestňovací program nepodporuje formát @extension@',
	'erreur_teleporter_methode_inconue' => 'Premiestňovací program nepozná metódu @methode@',
	'erreur_teleporter_type_fichier_inconnu' => 'Neznámy typ súboru pre zdroj @source@',
	'erreurs_xml' => 'Niektoré opisy XML sa nedajú prečítať',
	'explication_destination' => 'Ak nevyplníte umiestnenie, určí sa podľa názvu archívu.',

	// F
	'fieldset_debug' => 'Ladiť',
	'fieldset_edition' => 'Upraviť',
	'fieldset_fonctionnement' => 'Fungovanie',
	'filtrer' => 'Filtrovať',

	// I
	'info_0_plugin' => 'žiaden zásuvný modul',
	'info_1_depot' => '1 depozitár',
	'info_1_paquet' => '1 balík',
	'info_1_plugin' => '1 zásuvný modul',
	'info_admin_plugin_actif_non_verrou_non' => 'Na tejto stránke sa nachádza zoznam neaktívnych zásuvných modulov. Tieto zásuvné moduly sú vždy odomknuté.',
	'info_admin_plugin_actif_non_verrou_tous' => 'Na tejto stránke sa nachádzajú neaktívne zásuvné moduly. Tieto zásuvné moduly sú vždy odomknuté.',
	'info_admin_plugin_actif_oui_verrou_non' => 'Na tejto stránke sa nachádza zoznam aktívnych a neuzamknutých zásuvných modulov.',
	'info_admin_plugin_actif_oui_verrou_tous' => 'Na tejto stránke sa nachádzajú aktívne zásuvné moduly, či už sú uzamknuté alebo nie.',
	'info_admin_plugin_verrou_non' => 'Na tejto stránke sa nachádza zoznam odomknutých zásuvných modulov, či aktívnych alebo neaktívnych.',
	'info_admin_plugin_verrou_tous' => 'Na tejto stránke sa nachádza zoznam všetkých zásuvných modulov stránky.',
	'info_admin_plugin_verrouille' => 'Na tejto stránke je zoznam  aktivovaných a zamknutých zásuvných modulov (umiestnených na úložisku <code>@dir_plugins_dist@</code>).
	Ak ich chcete deaktivovať,
	kontaktujte webmastera stránky
	alebo si prečítajte <a href="http://programmer.spip.org/repertoire_plugins_dist">dokumentáciu.</a>',
	'info_adresse_spipzone' => 'SPIP-Zone – Zásuvné moduly',
	'info_ajouter_depot' => 'Ak pridáte depozitáre do svojej databázy, budete môcť o nich získať informácie a vyhľadať všetky balíky, ktoré sa v nich nachádzajú. <br />Depozitár opisuje súbor XML, v ktorom sa nachádzajú informácie o depozitári a všetkých jeho balíkoch.',
	'info_aucun_depot' => 'žiaden depozitár',
	'info_aucun_depot_ajoute' => 'Žiaden depozitár nie je k dispozícii!<br /> Na pridanie depozitára "SPIP-Zone - Plugins", ktorého adresa je vyplnená automaticky, alebo iného depozitára podľa svojho výberu použite formulár.',
	'info_aucun_paquet' => 'žiaden balík',
	'info_aucun_plugin' => 'žiaden zásuvný modul',
	'info_boite_charger_plugin' => '<strong>Táto stránka je k dispozícii iba pre webmasterov.</strong><p>Umožňuje vám vyhľadať zásuvné moduly z depozitárov uložených vo vašich nastaveniach a fyzicky ich nainštalovať na váš server</p>',
	'info_boite_depot_gerer' => '<strong>Táto stránka je k dispozícii iba pre webmasterov.</strong><p>Umožňuje im pridávať a aktualizovať depozitáre so zásuvnými modulmi.</p>',
	'info_charger_plugin' => 'Ak chcete pridať jeden alebo viac zásuvných modulov SPIPu, vyhľadajte ich v "galaxii" cez vyhľadávanie podľa viacerých kritérií. Do vyhľadávania budú zaradené len zásuvné moduly kompatibilné s nainštalovanou verziou SPIPu a zásuvné moduly, ktoré sú aktívne, budú označené.',
	'info_compatibilite_dependance' => 'Pre @compatibilite@:',
	'info_contributions_hebergees' => '@total_autres@ iný(ch) príspevok (-kov) na serveri',
	'info_critere_phrase' => 'Zadajte kľúčové slová, ktoré sa majú vyhľadávať v predpone, názve, slogane, opise a menách autorov zásuvných modulov',
	'info_depots_disponibles' => '@total_depots@ depozitár(ov/e)',
	'info_fichier_depot' => 'Zadajte adresu súboru s opisom depozitára, ktorý sa má pridať.<br />Ak chcete pridať depozitár "SPIP-Zone – Plugins", kliknite na tento odkaz: ', # MODIF
	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ a @signe_max@ @version_max@',
	'info_nb_depots' => '@nb@ depozitárov',
	'info_nb_paquets' => '@nb@ balíkov',
	'info_nb_plugins' => '@nb@ zásuvných modulov',
	'info_paquets_disponibles' => '@total_paquets@ dostupný(ch) balík(ov)',
	'info_plugin_attente_dependance' => 'chýbajú závislosti',
	'info_plugin_incompatible' => 'nekompatibilná verzia',
	'info_plugin_installe' => 'už je nainštalovaný',
	'info_plugin_obsolete' => 'zastaraná verzia',
	'info_plugins_disponibles' => '@total_plugins@ dostupný(ch) zásuvný(ch) modul(ov)',
	'info_plugins_heberges' => '@total_plugins@ zásuvný(ch) modul(ov) na serveri',
	'info_tri_nom' => 'zoradené v abecednom poradí',
	'info_tri_score' => 'zoradenie zostupne podľa relevantnosti',
	'info_type_depot_git' => 'Depozitár spravovaný cez GIT',
	'info_type_depot_manuel' => 'Depozitár spravovaný manuálne',
	'info_type_depot_svn' => 'Depozitár spravovaný cez SVN',
	'info_verrouille' => 'Tento zásuvný modul sa nedá deaktivovať alebo odinštalovať.',
	'installation_en_cours' => 'Požadované akcie sa vykonávajú',

	// L
	'label_1_autre_contribution' => 'iný príspevok',
	'label_actualise_le' => 'Aktualizovaný',
	'label_archive' => 'Internetová adresa archívu',
	'label_branches_spip' => 'Kompatibilný',
	'label_compatibilite_spip' => 'Kompatibilita',
	'label_critere_depot' => 'Depozitáre',
	'label_critere_doublon' => 'Kompatibilita',
	'label_critere_etat' => 'Stavy',
	'label_critere_phrase' => 'Vyhľadávať v zásuvných moduloch',
	'label_destination' => 'Cesta z priečinka "auto" k zásuvnému modulu',
	'label_etat' => 'Stav',
	'label_modifie_le' => 'Zmenený',
	'label_n_autres_contributions' => 'iné príspevky',
	'label_prefixe' => 'Predpona',
	'label_selectionner_plugin' => 'Vybrať tento zásuvný modul',
	'label_tags' => 'Tagy',
	'label_type_depot' => 'Typ depozitára:',
	'label_type_depot_git' => 'Depozitár pod GITom',
	'label_type_depot_manuel' => 'Manuálny depozitár',
	'label_type_depot_svn' => 'Depozitár pod SVN',
	'label_url_archives' => 'URL priečinka s archívmi',
	'label_url_brouteur' => 'URL koreňového adresára zdrojov',
	'label_url_serveur' => 'URL servera',
	'label_version' => 'Verzia',
	'label_xml_depot' => 'Súbor XML depozitára',
	'label_xml_plugin' => 'XML',
	'legende_installer_plugins' => 'Nainštalovať zásuvné moduly',
	'legende_rechercher_plugins' => 'Hľadať zásuvné moduly',
	'lien_demo' => 'Ukážka',
	'lien_documentation' => 'Dokumentácia',

	// M
	'message_action_finale_get_fail' => 'Zásuvný modul "@plugin@" (verzia: @version@) sa nepodarilo správne obnoviť',
	'message_action_finale_get_ok' => 'Zásuvný modul "@plugin@" (verzia: @version@) bol úspešne obnovený',
	'message_action_finale_getlib_fail' => 'Inštalácia knižnice "@plugin@" sa nepodarila',
	'message_action_finale_getlib_ok' => 'Knižnica "@plugin@" bola nainštalovaná',
	'message_action_finale_geton_fail' => 'Stiahnutie alebo aktivácia zásuvného modulu "@plugin@" (verzia: @version@) neprebehla správne',
	'message_action_finale_geton_ok' => 'Stiahnutie a aktivácia zásuvného modulu "@plugin@" (verzia: @version@) prebehli úspešne',
	'message_action_finale_install_fail' => 'Inštalácia zásuvného modulu "@plugin@" (verzia: @version@) sa nepodarila',
	'message_action_finale_install_ok' => 'Inštalácia zásuvného modulu "@plugin@" (verzia: @version@) bola úspešne dokončená',
	'message_action_finale_kill_fail' => 'Súbory zásuvného modulu "@plugin@" (verzia: @version@) sa nedajú úplne odstrániť',
	'message_action_finale_kill_ok' => 'Súbory zásuvného modulu "@plugin@" (verzia: @version@) boli úspešne odstránené',
	'message_action_finale_off_fail' => 'Deaktivácia zásuvného modulu "@plugin@" (verzia: @version@) nebola úspešne dokončená',
	'message_action_finale_off_ok' => 'Deaktivácia zásuvného modulu "@plugin@" (verzia: @version@) bola úspešne dokončená',
	'message_action_finale_on_fail' => 'Aktivácia zásuvného modulu "@plugin@" (verzia: @version@) nebola úspešne dokončená',
	'message_action_finale_on_ok' => 'Aktivácia zásuvného modulu "@plugin@" (verzia: @version@) bola úspešne dokončená',
	'message_action_finale_stop_fail' => 'Odinštalovanie zásuvného modulu "@plugin@" (verzia: @version@) nebolo dokončené úspešne',
	'message_action_finale_stop_ok' => 'Aktivácia zásuvného modulu "@plugin@" (verzia: @version@) bola úspešne dokončená',
	'message_action_finale_up_fail' => 'Aktualizácia zásuvného modulu "@plugin@" (z verzie: @version@ na @version_maj@) neprebehla správne',
	'message_action_finale_up_ok' => 'Aktualizácia zásuvného modulu "@plugin@" (z verzie: @version@ na @version_maj@) prebehla úspešne',
	'message_action_finale_upon_fail' => 'Aktualizácia a aktivácia zásuvného modulu "@plugin@" (z verzie: @version@ na @version_maj@) neprebehla úspešne',
	'message_action_finale_upon_ok' => 'Aktualizácia a aktivácia zásuvného modulu "@plugin@" (z verzie: @version@ na @version_maj@) bola úspešne dokončená',
	'message_action_get' => 'Stiahnuť zásuvný modul "@plugin@" (verzia: @version@)',
	'message_action_getlib' => 'Stiahnuť knižnicu "<a href="@version@" class="spip_out">@plugin@</a>"',
	'message_action_geton' => 'Stiahnuť a aktivovať zásuvný modul "@plugin@" (verzia: @version@)',
	'message_action_install' => 'Nainštaluje sa zásuvný modul "@plugin@" (verzia: @version@)',
	'message_action_kill' => 'Odstraňujú sa súbory zásuvného modulu "@plugin@" (verzia: @version@)',
	'message_action_off' => 'Deaktivovať zásuvný modul "@plugin@" (verzia: @version@)',
	'message_action_on' => 'Aktivovať zásuvný modul "@plugin@" (verzia: @version@)',
	'message_action_stop' => 'Odinštalovať zásuvný modul "@plugin@" (verzia: @version@)',
	'message_action_up' => 'Aktualizácia zásuvného modulu "@plugin@" (verzie @version@ na  @version_maj@)',
	'message_action_upon' => 'Aktualizácia a aktivácia zásuvného modulu "@plugin@" (verzia: @version@)',
	'message_dependance_extension_php' => 'Zásuvný modul @plugin@ si vyžaduje rozšírenie PHP @dependance@.',
	'message_dependance_php' => 'Zásuvný modul @plugin@ si vyžaduje @dependance@',
	'message_dependance_plugin' => 'Zásuvný modul @plugin@ závisí na zásuvnom module @dependance@.',
	'message_erreur_aucun_plugin_selectionne' => 'Nevybrali ste žiaden zásuvný modul.',
	'message_erreur_ecriture_lib' => '@plugin@ potrebuje knižnicu <a href="@lib_url@">@lib@</a>  umiestnenú v priečinku <var>lib/</var> koreňového adresára vašej stránky. Tento priečinok však neexistuje, alebo sa doň nedá zapisovať. Musíte manuálne nainštalovať knižnicu
alebo vytvoriť tento priečinok a nastaviť mu povolenie na zápis.',
	'message_erreur_maj_inconnu' => 'Neznámy zásuvný modul sa nedá aktualizovať.',
	'message_erreur_plugin_introuvable' => 'Nedá sa nájsť zásuvný modul @plugin@ na @action@.',
	'message_erreur_plugin_non_actif' => 'Nedá sa deaktivovať zásuvný modul, ktorý nebol aktivovaný.',
	'message_incompatibilite_spip' => '@plugin@  nie je kompatibilný s verziou SPIPu, ktorú používate.',
	'message_nok_aucun_depot_disponible' => 'Žiaden zásuvný modul nie je dostupný! Prejdite, prosím, na stránku riadenia depozitárov a pridajte zásuvné moduly.',
	'message_nok_aucun_paquet_ajoute' => 'Depozitáre "@url@" neponúka v porovnaní s databázou zaregistrovaných balíkov žiaden nový balík. Nebol do depozitára pridaný.',
	'message_nok_aucun_plugin_selectionne' => 'Nevybrali ste žiadne zásuvné moduly. Vyberte, prosím, zásuvné moduly, ktoré sa majú nainštalovať',
	'message_nok_champ_obligatoire' => 'Toto pole je povinné',
	'message_nok_depot_deja_ajoute' => 'Adresa "@url@" patrí depozitáru, ktorý bol už pridaný',
	'message_nok_maj_introuvable' => 'Aktualizácia zásuvného modulu @plugin@ sa nenašla.',
	'message_nok_plugin_inexistant' => 'Požadovaný zásuvný modul neexistuje (@plugin@).',
	'message_nok_sql_insert_depot' => 'Pri pridávaní depozitára @objet@ sa vyskytla chyba SQL',
	'message_nok_url_archive' => 'URL archívu je neplatná',
	'message_nok_url_depot_incorrecte' => 'Adresa "@url@" je nesprávna',
	'message_nok_xml_non_conforme' => 'Súbor XML, ktorý je opisom depozitára  "@fichier@",  nie je kompatibilný',
	'message_nok_xml_non_recupere' => 'Súbor XML " @fichier@ " sa nepodarilo získať',
	'message_ok_aucun_plugin_trouve' => 'Vybraným kritériám nevyhovuje žiaden zásuvný modul.',
	'message_ok_depot_ajoute' => 'Depozitár "@url@" bol priadaný.',
	'message_ok_plugins_trouves' => 'Vybraným kritériám (@tri@) vyhovuje @nb_plugins@ zásuvný(ch) modul(ov). Vyberte si tie zásuvné moduly, ktoré chcete stiahnuť a aktivovať na svojom serveri.',
	'message_telechargement_archive_effectue' => 'Archív bol úspešne rozbalený do priečinka @dir@.',

	// N
	'nettoyer_actions' => 'Vymazať tieto akcie! Takto vymažete zoznam akcií, ktoré ešte treba vykonať.',

	// O
	'onglet_depots' => 'Spravovať depozitáre',
	'option_depot_tout' => 'Všetky depozitáre',
	'option_doublon_non' => 'Najnovšia verzia',
	'option_doublon_oui' => 'Všetky kompatibilné verzie',
	'option_etat_tout' => 'Všetky stavy',

	// P
	'placeholder_phrase' => 'predpona, názov, slogan, opis alebo autor',
	'plugin_info_actif' => 'Aktívny zásuvný modul',
	'plugin_info_up' => 'K dispozícii je aktualizácia zásuvného modulu (verzia @version@)', # MODIF
	'plugin_info_verrouille' => 'Zamknutý zásuvný modul',
	'plugins_inactifs_liste' => 'Neaktívne',
	'plugins_non_verrouilles_liste' => 'Nezamknuté',
	'plugins_verrouilles_liste' => 'Zamknuté',

	// R
	'resume_table_depots' => 'Zoznam pridaných depozitárov',
	'resume_table_paquets' => 'Zoznam balíkov',
	'resume_table_plugins' => 'Zoznam zásuvných modulov @categorie@',

	// T
	'telecharger_archive_plugin_explication' => 'Môžete si stiahnuť archív,  ktorý sa postará
		o zápis internetovej adresy archívu do poľa pre vstup od používateľa vo vašom priečinku "plugins/auto".',
	'titre_depot' => 'Depozitár',
	'titre_depots' => 'Depozitáre',
	'titre_form_ajouter_depot' => 'Pridať depozitár',
	'titre_form_charger_plugin' => 'Vyhľadať a pridať zásuvné moduly',
	'titre_form_charger_plugin_archive' => 'Stiahnuť zásuvný modul z archívu',
	'titre_form_configurer_svp' => 'Nastaviť server zásuvných modulov',
	'titre_liste_autres_contributions' => 'Šablóny, knižnice, sady ikon...',
	'titre_liste_autres_depots' => 'Ostatné depozitáre',
	'titre_liste_depots' => 'Zoznam dostupných depozitárov',
	'titre_liste_paquets_plugin' => 'Zoznam balíkov zásuvného modulu',
	'titre_liste_plugins' => 'Zoznam zásuvných modulov',
	'titre_logo_depot' => 'Logo depozitára',
	'titre_logo_plugin' => 'Logo zásuvného modulu',
	'titre_nouveau_depot' => 'Nový depozitár',
	'titre_page_configurer' => 'Server zásuvných modulov',
	'titre_paquet' => 'Balík',
	'titre_paquets' => 'Balíky',
	'titre_plugin' => 'Zásuvný modul',
	'titre_plugins' => 'Zásuvné moduly',
	'tout_cocher' => 'Označiť všetky',
	'tout_cocher_up' => 'Vyhľadať aktualizácie',
	'tout_decocher' => 'Odznačiť všetky',
];
